==> foundation-core-domain-1.0.54.tgz: package/models/dashboardOrganisations/dashboardOrganisationInfos.ts <==
import type { ApplicationScope } from "@dative-gpi/foundation-shared-domain/enums";

export class DashboardOrganisationInfos {
  id: string;
  dashboardId: string;
  organisationId: string;
  folderId: string | null;
  folderLabel: string | null;
  folderIcon: string | null;
  imageId: string | null;
  scope: ApplicationScope;
  locked: boolean;
  label: string;
  code: string;
  icon: string;
  tags: string[];
  colors: string[];

  constructor(params: DashboardOrganisationInfosDTO) {
    this.id = params.id;
    this.dashboardId = params.dashboardId;
    this.organisationId = params.organisationId;
    this.folderId = params.folderId;
    this.folderLabel = params.folderLabel;
    this.folderIcon = params.folderIcon;
    this.imageId = params.imageId;
    this.scope = params.scope;
    this.locked = params.locked;
    this.label = params.label;
    this.code = params.code;
    this.icon = params.icon;
    this.tags = params.tags.slice();
    this.colors = params.colors.slice();
  }
}

export interface DashboardOrganisationInfosDTO {
  id: string;
  dashboardId: string;
  organisationId: string;
  folderId: string | null;
  folderLabel: string | null;
  folderIcon: string | null;
  imageId: string | null;
  scope: ApplicationScope;
  locked: boolean;
  label: string;
  code: string;
  icon: string;
  tags: string[];
  colors: string[];
}

export interface DashboardOrganisationFilters {
  dashboardOrganisationIds?: string[] | null;
  root?: boolean | null;
  folderId?: string | null;
  search?: string | null;
}

==> foundation-core-domain-1.0.116.tgz: package/models/dashboardOrganisations/dashboardOrganisationInfos.ts <==
import type { ApplicationScope } from "@dative-gpi/foundation-shared-domain/enums";

export class DashboardOrganisationInfos {
  id: string;
  dashboardId: string;
  organisationId: string;
  folderId: string | null;
  folderLabel: string | null;
  folderIcon: string | null;
  imageId: string | null;
  scope: ApplicationScope;
  locked: boolean;
  label: string;
  code: string;
  icon: string;
  tags: string[];
  colors: string[];

  constructor(params: DashboardOrganisationInfosDTO) {
    this.id = params.id;
    this.dashboardId = params.dashboardId;
    this.organisationId = params.organisationId;
    this.folderId = params.folderId;
    this.folderLabel = params.folderLabel;
    this.folderIcon = params.folderIcon;
    this.imageId = params.imageId;
    this.scope = params.scope;
    this.locked = params.locked;
    this.label = params.label;
    this.code = params.code;
    this.icon = params.icon;
    this.tags = params.tags.slice();
    this.colors = params.colors.slice();
  }
}

export interface DashboardOrganisationInfosDTO {
  id: string;
  dashboardId: string;
  organisationId: string;
  folderId: string | null;
  folderLabel: string | null;
  folderIcon: string | null;
  imageId: string | null;
  scope: ApplicationScope;
  locked: boolean;
  label: string;
  code: string;
  icon: string;
  tags: string[];
  colors: string[];
}

export interface DashboardOrganisationFilters {
  dashboardOrganisationsIds?: string[] | null;
  root?: boolean | null;
  folderId?: string | null;
  search?: string | null;
}
